package examples.guestbook;

import freemarker.template.*;
import java.util.TimeZone;
import java.text.DateFormat;

public class GuestbookEntryTM implements TemplateHashModel {

    private final GuestbookEntry entry;

    private SimpleNumber number;
    private SimpleScalar date;
    private SimpleScalar name;
    private SimpleScalar message;

    public GuestbookEntryTM(GuestbookEntry entry) {
        this.entry = entry;
    }

    public TemplateModel get(String key) throws TemplateModelException {
        if ("number".equals(key)) {
            return getNumber();
        } else if ("date".equals(key)) {
            return getDate();
        } else if ("name".equals(key)) {
            return getName();
        } else if ("message".equals(key)) {
            return getMessage();
        } else {
            return null;
        }
    }

    private TemplateModel getNumber() {
        if (number == null) {
            number = new SimpleNumber(entry.getNumber());
        }
        return number;
    }

    private TemplateModel getDate() {
        if (date == null) {
            DateFormat dateFormat = DateFormat.getDateTimeInstance(
                    DateFormat.MEDIUM, DateFormat.LONG);
            dateFormat.setTimeZone(TimeZone.getTimeZone("GMT"));
            date = new SimpleScalar(dateFormat.format(entry.getDate()));
        }
        return date;
    }

    private TemplateModel getName() {
        if (name == null) {
            name = new SimpleScalar(entry.getName());
        }
        return name;
    }

    private TemplateModel getMessage() {
        if (message == null) {
            message = new SimpleScalar(entry.getMessage());
        }
        return message;
    }

    public boolean isEmpty() throws TemplateModelException {
        return (entry == null);
    }
}
