package examples;

import java.io.*;
import javax.servlet.*;
import javax.servlet.http.*;
import freemarker.template.*;
import freemarker.template.TemplateFactory;

public class HelloServlet extends HttpServlet {

	private Template template;

	public void init(ServletConfig config) throws ServletException {
		super.init(config);
		String templatePath = getServletContext().getRealPath("/hello-world.html");
		try {
			template = TemplateFactory.INSTANCE.createFromFile(templatePath);
		} catch (IOException e) {
			throw new UnavailableException( "Can't load template " +
				templatePath + ": " + e.toString() );
		}
	}

	public void doGet(HttpServletRequest req, HttpServletResponse res)
            throws IOException {

		res.setContentType("text/html");
		PrintWriter out = res.getWriter();

		// Make a template data model.
		SimpleHash modelRoot = new SimpleHash();
		modelRoot.put("message", new SimpleScalar("Hello, world!"));

		// Process the template.
        TemplateProcessorParameters tpp =
                TemplateProcessorParameters.newInstance(out)
                        .withModel(modelRoot);
		template.process(tpp);
		out.close();
	}

	public void doPost(HttpServletRequest req, HttpServletResponse res)
            throws IOException {
		doGet(req, res);
	}
}
