/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2013 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.engine;

/**
 * Constants to be supplied to {@link FMEngine} to configure the engine's
 * runtime behaviour. These are supplied using the {@link FMEngine#setObject(String, Object)
 * setObject()} method of the <code>FMEngine</code> class.
 * <p>
 * These are appropriate when runtime objects need to be created by calling
 * code, or it is otherwise inappropriate to use reflection to create them.
 * </p>
 *
 * @author Nicholas Cull
 * @version $Id: PropertyObjectConstants.java 1172 2013-04-21 10:00:22Z run2000 $
 * @since 1.9
 */
public final class PropertyObjectConstants {

    private PropertyObjectConstants() {
    }

    /**
     * A <code>CachingStrategy</code> object to be used for retrieving and
     * caching templates. The object should be fully configured and ready to go.
     * @see freemarker.template.cache.CachingStrategy
     */
    public static final String TEMPLATE_CACHING_STRATEGTY = "template.cache.strategy";
    /**
     * A <code>TemplateRuntimeHandler</code> object to be used for reporting
     * error messages to the template runtime.
     * @see freemarker.template.TemplateRuntimeHandler
     */
    public static final String TEMPLATE_RUNTIME_HANDLER = "template.runtime.handler";
    /**
     * A <code>TemplateTransformModel</code> or <code>TemplateTransformModel2</code>
     * for escaping variables written to the <code>Writer</code>.
     * @see freemarker.template.TemplateTransformModel
     * @see freemarker.template.TemplateTransformModel2
     */
    public static final String TEMPLATE_RUNTIME_ESCAPE = "template.runtime.escape";
    /**
     * A <code>TemplateTransformModel</code> or <code>TemplateTransformModel2</code>
     * that filters all output from the template.
     * @see freemarker.template.TemplateTransformModel
     * @see freemarker.template.TemplateTransformModel2
     */
    public static final String TEMPLATE_RUNTIME_GLOBAL_FILTER = "template.runtime.global.filter";

}
