/*
 * ====================================================================
 *
 * Copyright (c) 2000 Attila Szegedi.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution, if
 *    any, must include the following acknowlegement:
 *       "This product includes the Expose library
 *        (http://www.szegedi.org/expose)."
 *    Alternately, this acknowlegement may appear in the software itself,
 *    if and wherever such third-party acknowlegements normally appear.
 *
 * 4. The names "Expose" and "Attila Szegedi" must not be used to endorse
 *    or promote products derived from this software without prior written
 *    permission. For written permission, please contact expose@szegedi.org.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR ITS CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
 * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
 * IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * ====================================================================
 *
 */

package freemarker.ext.beans;

import freemarker.template.*;

import java.io.Serializable;

/**
 * Various predefined singleton models.
 *
 * @author Attila Szegedi, attila@szegedi.org
 * @version $Id: Models.java 1101 2013-04-01 04:17:32Z run2000 $
 * @deprecated this class is deprecated in favour of the classes in the
 * {@link freemarker.ext.beans2} package
 */
public final class Models
{
	private Models()
	{
	}

	/**
	 * A singleton empty scalar. It is an instance of <code>EmptyScalar</code>.
	 */
	public static final TemplateScalarModel EMPTY_SCALAR = new EmptyScalar();

	/**
	 * This inner class is public so that reflected method invocations have access
	 * (kind of implementation detail).
	 * It is a singleton, whose single instance is {@link Models#EMPTY_SCALAR}.
	 */
	private static final class EmptyScalar implements TemplateScalarModel,
            Serializable
	{
        /** Serialization UUID for this class. */
        private static final long serialVersionUID = -4867105975619160749L;

		/**
		 * Returns a zero-length string.
		 */
		public String getAsString() { return ""; }

		/**
		 * Returns true.
		 */
		public boolean isEmpty() { return true; }
	}
}
