/*
 * ====================================================================
 *
 * Copyright (c) 2000 Attila Szegedi.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution, if
 *    any, must include the following acknowlegement:
 *       "This product includes the Expose library
 *        (http://www.szegedi.org/expose)."
 *    Alternately, this acknowlegement may appear in the software itself,
 *    if and wherever such third-party acknowlegements normally appear.
 *
 * 4. The names "Expose" and "Attila Szegedi" must not be used to endorse
 *    or promote products derived from this software without prior written
 *    permission. For written permission, please contact expose@szegedi.org.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR ITS CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
 * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
 * IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * ====================================================================
 *
 */

package freemarker.ext.beans;

import freemarker.template.*;

import java.io.Serializable;
import java.io.ObjectStreamException;

/**
 * Utility class for instantiating {@link StaticModel} instances from
 * templates. If your template's data model contains an instance of
 * StaticModels (named, say <code>StaticModels</code>), then you can
 * instantiate an arbitrary StaticModel using get syntax (i.e.
 * <code>StaticModels["java.lang.System"]</code>).
 *
 * @author Attila Szegedi, attila@szegedi.org
 * @version $Id: StaticModels.java 1101 2013-04-01 04:17:32Z run2000 $
 * @deprecated this class is deprecated in favour of the classes in the
 * {@link freemarker.ext.beans2} package
 */
public final class StaticModels implements TemplateHashModel, Serializable
{
	/** The single instance of the class. */
	public static final StaticModels INSTANCE = new StaticModels();

    /** Serialization UUID for this class. */
    private static final long serialVersionUID = 5125147490812816915L;

	private StaticModels()
	{
	}

    /**
     * Return a singleton instance of this class.
     *
     * @return the singleton instance of this class
     */
    public static StaticModels getInstance() {
        return INSTANCE;
    }

	/**
	 * Returns a {@link StaticModel} for the fully qualified class name
	 * passed as the key.
	 */
	public TemplateModel get(String key)
	throws
		TemplateModelException
	{
		try
		{
			return StaticModel.create(Class.forName(key));
		}
		catch(ClassNotFoundException e)
		{
			throw new TemplateModelException("Class not found: \"" + key + '"');
		}
	}

	public boolean isEmpty()
	{
		return false;
	}

    /**
     * For serialization purposes, always resolve a de-serialized object
     * back to the singleton instance. This ensures that any strict equality
     * tests remain valid after serialization.
     */
    private Object readResolve() throws ObjectStreamException {
        return INSTANCE;
    }
}
