/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2005 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */
package freemarker.ext.beans2;

import freemarker.template.TemplateModel;
import freemarker.template.TemplateModelException;
import freemarker.template.TemplateObjectModel;
import freemarker.template.FastBoolean;

/**
 * Returns a boolean value for a given object model.
 *
 * @author Nicholas Cull
 * @version $Id: ConvertToBool.java 1067 2011-06-06 10:55:28Z run2000 $
 * @since 1.9
 */
public class ConvertToBool implements Converter {

    private static final ConvertToBool instance = new ConvertToBool();

    /** Private constructor to indicate this is a singleton class. */
    private ConvertToBool() {
    }

    /**
     * Returns the singleton instance of this converter.
     *
     * @return the singleton instance of this converter
     */
    public static ConvertToBool getInstance() {
        return instance;
    }

    public Object convert( TemplateModel model )
            throws IllegalArgumentException, NullPointerException,
            TemplateModelException {

        TemplateObjectModel objectModel = (TemplateObjectModel) model;
        return objectModel.getAsObject();
    }

    public boolean converts( TemplateModel model, Class<?> target ) {

        if( !( model instanceof FastBoolean )) {
            return false;
        }
        return( target == Boolean.TYPE );
    }
}
