/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2005 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */
package freemarker.ext.beans2;

import java.util.HashSet;
import java.util.Set;

import freemarker.template.TemplateModel;
import freemarker.template.TemplateModelException;
import freemarker.template.TemplateListModel;
import freemarker.template.TemplateListModel2;
import freemarker.template.TemplateIteratorModel;

/**
 * Returns a HashSet object for a given list model.
 *
 * @author Nicholas Cull
 * @version $Id: ConvertToHashSet.java 1067 2011-06-06 10:55:28Z run2000 $
 * @since 1.9
 */
public class ConvertToHashSet implements Converter {

    private static final ConvertToHashSet instance = new ConvertToHashSet();

    /** Private constructor to indicate this is a singleton class. */
    private ConvertToHashSet() {
    }

    /**
     * Returns the singleton instance of this converter.
     *
     * @return the singleton instance of this converter
     */
    public static ConvertToHashSet getInstance() {
        return instance;
    }

    public Object convert( TemplateModel model )
            throws IllegalArgumentException, NullPointerException,
            TemplateModelException {

        if( model instanceof TemplateListModel ) {
            TemplateListModel listModel = (TemplateListModel) model;
            if( listModel.isEmpty() ) {
                return null;
            }
            Set<Object> result = new HashSet<Object>();
            if( ! listModel.isRewound() ) {
                listModel.rewind();
            }
            while( listModel.hasNext() ) {
                TemplateModel item = listModel.next();
                result.add( Unwrapper.defaultUnwrap( item ));
            }
            return result;
        } else {
            TemplateListModel2 listModel = (TemplateListModel2) model;
            if( listModel.isEmpty() ) {
                return null;
            }
            Set<Object> result = new HashSet<Object>();
            TemplateIteratorModel iterator = listModel.templateIterator();
            while( iterator.hasNext() ) {
                TemplateModel item = iterator.next();
                result.add( Unwrapper.defaultUnwrap( item ));
            }
            return result;
        }
    }

    public boolean converts( TemplateModel model, Class<?> target ) {

        if(!( model instanceof TemplateListModel ) && !( model instanceof TemplateListModel2 )) {
            return false;
        }

        return ( target != null ) && ( target.isAssignableFrom( HashSet.class ));
    }
}
