/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2005 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */
package freemarker.ext.beans2;

import freemarker.template.TemplateModel;
import freemarker.template.TemplateModelException;
import freemarker.template.TemplateNumberModel;

/**
 * Returns a Short value for a given number model.
 *
 * @author Nicholas Cull
 * @version $Id: ConvertToShort.java 1067 2011-06-06 10:55:28Z run2000 $
 * @since 1.9
 */
public class ConvertToShort implements Converter {

    private static final ConvertToShort instance = new ConvertToShort();

    /** Private constructor to indicate this is a singleton class. */
    private ConvertToShort() {
    }

    /**
     * Returns the singleton instance of this converter.
     *
     * @return the singleton instance of this converter
     */
    public static ConvertToShort getInstance() {
        return instance;
    }

    public Object convert( TemplateModel model )
            throws IllegalArgumentException, NullPointerException,
            TemplateModelException {

        if( model.isEmpty() ) {
            return null;
        }

        TemplateNumberModel numberModel = (TemplateNumberModel) model;

        return new Short( (short)numberModel.getAsNumber() );
    }

    public boolean converts( TemplateModel model, Class<?> target ) {
        if( target == null ) {
            return false;
        }
        if( !( model instanceof TemplateNumberModel )) {
            return false;
        }

        return ( target == Short.class ) || ( target == Short.TYPE )
                || ( target == Number.class ) || ( target == Object.class );
    }
}
