/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2005 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */
package freemarker.ext.beans2;

import freemarker.template.TemplateIteratorModel;
import freemarker.template.TemplateModelException;
import freemarker.template.TemplateModel;

/**
 * Iterator model for accessing Enum values.
 *
 * @author Nicholas Cull
 * @version $Id: EnumIterator.java 1067 2011-06-06 10:55:28Z run2000 $
 * @since 1.9
 */
class EnumIterator<T extends Enum> implements TemplateIteratorModel {
    private T[] values;
    private int index = 0;

    /**
     * Constructor that takes all the values of an Enum class.
     *
     * @param values the values of the Enum class.
     */
    public EnumIterator(T[] values) {
        this.values = values;
    }

    /**
     * Do we have another item in the list?
     *
     * @return <code>true</code> if there are more items to be iterated over,
     *         otherwise <code>false</code>
     * @throws freemarker.template.TemplateModelException
     *          there was a problem determining the
     *          next item in the list
     */
    public boolean hasNext() throws TemplateModelException {
        return index < values.length;
    }

    /**
     * Retrieve the next item in the list. The item will be a <code>TemplateModel</code>
     * containing the underlying value.
     *
     * @return the next item in the list
     * @throws freemarker.template.TemplateModelException
     *          the next item couldn't be retrieved,
     *          or we're at the end of the list
     */
    public TemplateModel next() throws TemplateModelException {
        return Wrapper.wrap( values[ index++ ]);
    }

    /**
     * Is the object empty?
     *
     * @return <code>true</code> if this object is empty, otherwise <code>false</code>
     */
    public boolean isEmpty() throws TemplateModelException {
        return (values == null) || (values.length == 0);
    }
}
