/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2005 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */
package freemarker.ext.beans2;

import freemarker.template.*;

import java.util.Iterator;
import java.io.Serializable;

/**
 * Wraps Iterable objects by providing a template iterator model. Also a base
 * class for CollectionWrapper.
 *
 * @author Nicholas Cull
 * @version $Id: IterableWrapper.java 1067 2011-06-06 10:55:28Z run2000 $
 * @since 1.9
 */
public class IterableWrapper<T extends Iterable> extends BeanWrapper<T>
        implements TemplateListModel2, Serializable {

    /** Serialization UUID for this class */
    private static final long serialVersionUID = -3630522556027898051L;

    /**
     * Default constructor where an object is not provided initially. This allows
     * the wrapper to be used as a prototype.
     */
    public IterableWrapper() {
    }

    /**
     * Constructor that takes an Iterable object to be wrapped.
     *
     * @param object the iterable object to be wrapped
     */
    public IterableWrapper( T object ) {
        super( object );
    }

    /**
     * Retrieves an iterator to iterate over this collection.
     *
     * @return an iterator to iterate over the current list.
     * @throws freemarker.template.TemplateModelException
     *          the next item in the list can't be
     *          retrieved, or no next item exists.
     */
    public TemplateIteratorModel templateIterator() throws TemplateModelException {
        Iterable coll = object;
        return new IteratorWrapper<Iterator>( coll.iterator() );
    }

    /**
     * Returns the used iterator to the list model.
     *
     * @param iterator the iterator to be returned
     */
    public void releaseIterator( TemplateIteratorModel iterator ) {
        // Do nothing
    }
}
