/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2005 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */
package freemarker.ext.beans2;

import freemarker.template.TemplateObjectModel;
import freemarker.template.TemplateScalarModel;
import freemarker.template.TemplateNumberModel;
import freemarker.template.TemplateModelException;

import java.io.Serializable;

/**
 * Wraps a Number object as a number model. Does not provide any additional
 * Bean methods.
 *
 * @author Nicholas Cull
 * @version $Id: NumberWrapper.java 1067 2011-06-06 10:55:28Z run2000 $
 * @since 1.9
 */
public class NumberWrapper implements TemplateNumberModel,
        TemplateScalarModel, TemplateObjectModel, ObjectWrapper, Serializable {

    /** Serialization UUID for this class */
    private static final long serialVersionUID = 2598422264571769120L;
    /** The number being wrapped by this wrapper */
    private Number object;

    /**
     * Default constructor where an object is not provided initially. This allows
     * the wrapper to be used as a prototype.
     */
    public NumberWrapper() {
    }

    /**
     * Constructor that takes a Number object to be wrapped.
     *
     * @param object the number object to be wrapped
     */
    public NumberWrapper( Number object ) {
        this.object = object;
    }

    public void setObject( Object object ) {
        this.object = (Number) object;
    }

    public boolean isEmpty() throws TemplateModelException {
        return object == null;
    }

    public String getAsString() throws TemplateModelException {
        return object.toString();
    }

    public long getAsNumber() throws TemplateModelException {
        return object.longValue();
    }

    public Object getAsObject() throws TemplateModelException {
        return object;
    }

    /**
     * Creates and returns a copy of this object.
     *
     * @return a clone of this instance.
     * @throws RuntimeException the clone operation was not successful
     * @throws OutOfMemoryError if there is not enough memory.
     * @see Cloneable
     */
    public Object clone() {
        try {
            return super.clone();
        } catch( CloneNotSupportedException e ) {
            throw new RuntimeException( "Clone method threw an exception: " + e.getMessage() );
        }
    }
}
