/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2005 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */
package freemarker.ext.beans2;

/**
 * An interface that allows an object to be wrapped. No matter what we're
 * wrapping, the wrapper will provide this interface.
 * <p>
 * This interface allows object wrappers to be handled as prototypes. A prototype
 * for the class of object will be created once, and all implementations of that
 * class will be wrapped using a clone of the wrapper.
 *
 * @author Nicholas Cull
 * @version $Id: ObjectWrapper.java 1067 2011-06-06 10:55:28Z run2000 $
 * @since 1.9
 */
public interface ObjectWrapper extends Cloneable {

    /**
     * Sets the object to be wrapped by this object wrapper.
     *
     * @param object the object to be wrapped
     */
    void setObject( Object object );

    /**
     * Creates and returns a copy of this object wrapper. This allows the object
     * wrapper to be used as a prototype.
     *
     * @return a clone of this instance
     */
    Object clone();
}
