/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2005 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */
package freemarker.ext.beans2;

import freemarker.template.TemplateListModel2;
import freemarker.template.TemplateIteratorModel;
import freemarker.template.TemplateModelException;

/**
 * Wraps a static Enum class. Subclasses StaticClassWrapper to provide an
 * Iterator model for all values of the enum.
 *
 * @since 1.9
 * @version $Id: StaticEnumWrapper.java 1067 2011-06-06 10:55:28Z run2000 $
 */
public class StaticEnumWrapper<T extends Enum> extends StaticClassWrapper<T>
        implements TemplateListModel2 {

    /**
     * Default constructor where a class is not provided initially. This allows
     * the wrapper to be used as a prototype.
     */
    public StaticEnumWrapper() {
    }

    /**
     * Constructor that takes am enum to be wrapped.
     *
     * @param clazz the enum class to be wrapped
     */
    public StaticEnumWrapper(Class<T> clazz) {
        super(clazz);
    }

    /**
     * Retrieves an iterator to iterate over this enumeration.
     *
     * @return an iterator to iterate over the current enumeration.
     */
    public TemplateIteratorModel templateIterator() throws TemplateModelException {
        Features<T> f = Wrapper.getClassFeatures( clazz );

        return new EnumIterator<T>( f.getEnumValues() );
    }

    /**
     * <p>Returns the used iterator to the enumeration.
     *
     * @param iterator the iterator to be returned
     */
    public void releaseIterator(TemplateIteratorModel iterator) {
        // Do nothing
    }
}
