/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2011 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.template;

import java.io.IOException;

/**
 * An interface for factory methods that can create <tt>Compileable</tt>
 * objects. The main example of a compileable object is a <tt>Template</tt>.
 *
 * @author Nicholas Cull
 * @version $I$
 * @since 1.9
 */
public interface CompileableFactory<T extends Compileable> {

    /**
     * Return a name for the compilable object created by this factory.
     *
     * @return the name of the object the implementing factory creates
     */
    String getName();

    /**
     * Create an instance of the compilable object from the given
     * InputStream.
     *
     * @param compileableParameters
     * @return a newly created compilable object from the given input stream
     * @throws IOException there was a problem reading from the input stream
     */
    T create(CompileableFactoryParameters compileableParameters) throws IOException;

}
