/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2004 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.template.expression;

/**
 * An interface for unary operators.
 *
 * @version $Id: Unary.java 1101 2013-04-01 04:17:32Z run2000 $
 */
public interface Unary extends Operator {

    /**
     * Indicates the operator association for this unary expression.
     */
    public enum Association {
        /** Indicates a prefix operator */
        PREFIX,
        /** Indicates a postfix operator */
        POSTFIX
    }

    /**
     * Sets the target for this unary operation.
     *
     * @throws IllegalArgumentException the target is of the wrong type
     * for this operator
     * @throws NullPointerException the argument is null
     */
    public void setTarget(Expression target);

    /**
     * Determines the operator association of the unary operation.
     *
     * @return Association of <code>PREFIX</code> or <code>POSTFIX</code>.
     */
    public Association getAssociationType();
}
