/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2004 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */
package freemarker.template.instruction;

import freemarker.template.TemplateModelException;
import freemarker.template.TemplateWriteableHashModel;

/**
 * Abstraction of a template hash model containing a live list iterator.
 * Provides methods for moving the iterator and resetting it at the end
 * of the iteration, if appropriate.
 *
 * @author Nicholas Cull
 * @version $Id: ListArgumentWrapper.java 1067 2011-06-06 10:55:28Z run2000 $
 * @since 1.9
 */
interface ListArgumentWrapper extends TemplateWriteableHashModel {

    /**
     * Update the hash model to reference the next item in the list.
     *
     * @return <code>true</code> if the iterator was advanced, otherwise
     * <code>false</code> to indicate the end of the list has been reached
     * @throws TemplateModelException there was a problem advancing the
     * iterator in the underlying list
     */
    boolean next() throws TemplateModelException;

    /**
     * Perform any cleanup required once the underlying list has been consumed.
     */
    void reset();

}
