/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2004 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.testcase;

import junit.framework.TestSuite;
import junit.framework.Test;

/**
 * Test suite for FM-Classic. The suite conforms to interface expected by
 * <a href="http://junit.sourceforge.net/" target="_top">JUnit</a> 3.7.
 *
 * @version $Id: FreeMarkerTestSuite.java 1107 2013-04-12 02:00:10Z run2000 $
 */
public final class FreeMarkerTestSuite {

    /** Default constructor, unused. */
    private FreeMarkerTestSuite() { }

    /**
     * Creates the test suite. The suite is used by JUnit to figure out which
     * tests to execute.
     *
     * @return a suite of tests to be executed by JUnit
     */
    public static Test suite() {
        TestSuite suite = new TestSuite();

        suite.addTest( new DummyTestCase( "dummyTestCase" ));
        suite.addTest( new TestComment( "commentTest" ));
        suite.addTest( new TestVariables( "variableTest" ));
        suite.addTest( new TestAssign( "assignTest" ));
        suite.addTest( new TestBoolean( "booleanTest" ));
        suite.addTest( new TestMultiModels( "multiModelTest" ));
        suite.addTest( new TestNoParse( "noParseTest" ));
        suite.addTest( new TestTransform( "transformTest" ));
        suite.addTest( new TestCompress( "compressionTest" ));
        suite.addTest( new TestLastCharacter( "lastCharacterTest" ));
        suite.addTest( new TestListIterators( "listIteratorTest" ));
        suite.addTest( new TestListLiteral( "listLiteralTest" ));
        suite.addTest( new TestHashLiteral( "hashLiteralTest" ));
        suite.addTest( new TestNumberLiteral( "numberLiteralTest" ));
        suite.addTest( new TestNewlines1( "newlineTest1" ));
        suite.addTest( new TestNewlines2( "newlineTest2" ));
        suite.addTest( new TestNewlines3( "newlineTest3" ));
        suite.addTest( new TestJavaTransform( "javaToHtmlTest" ));
        suite.addTest( new TestFreeMarkerTransform( "freeMarkerToHtmlTest" ));
        suite.addTest( new TestLog4jExceptionHandler( "log4jEventListenerTest" ));
        suite.addTest( new TestIdentifier( "testIdentifier" ));
        suite.addTest( new TestPrecedence( "testPrecedence" ));
        suite.addTest( new TestFunction( "testFunction" ));
        suite.addTest( new TestFunction2( "testFunction2" ));
        suite.addTest( new TestLocal( "testLocal" ));
        suite.addTest( new TestSwitchCase( "testSwitchCase" ));
        suite.addTest( new TestBreak( "testBreak" ));
        suite.addTest( new TestExtendedList( "testExtendedList" ));
        suite.addTest( new TestNumerics( "testNumerics" ));
        suite.addTest( new TestIterator( "testIterator" ));
        suite.addTest( new TestStringNumber( "testStringNumber" ));
        suite.addTest( new TestObjectModel( "testObjectModel" ));
        suite.addTest( new TestPerl5Substitute( "testPerl5Substitute" ));
        suite.addTest( new TestPerl5Methods( "testPerl5Methods" ));
        suite.addTest( new TestPipeline( "testPipeline" ));
        suite.addTest( new TestTypes( "testTypes" ));
        suite.addTest( new TestFormat( "testFormat" ));
        suite.addTest( new TestLambda( "testLambda" ));
        suite.addTest( new TestFunctional( "testFunctional" ));
        suite.addTest( new TestFunctionalTransform( "testFunctionalTransform" ));

        // This could be problematic, since it assumes a particular ordering
        // for keysets and values from a hash, which are ultimately
        // dependant on the implementation of the underlying JVM class library.
        //suite.addTest( new TestExtendedHash( "testExtendedHash" ));

        // These tests depend on the properties file being set up correctly
        suite.addTest( new TestLocalization( "testLocale" ));
        suite.addTest( new TestInclude( "testInclude" ));
        suite.addTest( new TestInclude2( "testInclude2" ));
        suite.addTest( new TestSerialModels( "testSerialModels" ));
        suite.addTest( new TestSerialization( "testSerialization" ));

        // Suite for the java.ext.beans package
        suite.addTestSuite( TestBeanModels.class );

        // Suite for the java.ext.beans2 package
        suite.addTestSuite( TestBeanModels2.class );

        // Suite for SimpleList and ExtendedList classes
        suite.addTestSuite( TestListModel.class );
        suite.addTestSuite( TestListModel2.class );
        suite.addTestSuite( TestHashModel.class );
        suite.addTestSuite( TestHashModel2.class );

        // These tests are problematic in an automatic suite --
        // commenting out for now.

        //suite.addTest( new TestException( "exceptionTest" ));
        //suite.addTest( new TestExecModel( "execTest" ));

        return suite;
    }

    /**
     * Main method for running the test suite. This uses the <code>textui</code>
     * implementation of the JUnit test runner.
     */
    public static void main (String[] args) {
        junit.textui.TestRunner.run( suite() );
    }
}
