/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2004 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.testcase;

import freemarker.template.*;
import freemarker.testcase.models.*;
import freemarker.ext.misc.HtmlFormattedExceptionListener;
import java.io.IOException;
import java.io.StringWriter;

import junit.framework.*;

/**
 * Test case for the situation where a template throws a
 * {@link freemarker.template.TemplateModelException}.
 *
 * @version $Id: TestException3.java 1101 2013-04-01 04:17:32Z run2000 $
 * @see TestException
 * @see TestException2
 */
public final class TestException3 extends AbstractTestCase {
    private FastHash modelRoot;

    /**
     * Constructor that passes the name of the test up to the JUnit
     * constructor.
     *
     * @param aTestname the name of the test
     */
    public TestException3(String aTestname) {
        super( aTestname );
    }

    /**
     * Set up the test case prior to running.
     */
    public void setUp() {
        setUpFiles( "test-exception3.html" );

        // Make a template data model.
        modelRoot = new FastHash();
        modelRoot.put( "message", new FastScalar( "Hello, world!" ) );
        modelRoot.put( "test", new ExceptionModel() );
    }

    /**
     * Performs the test. A fail result will generate information about
     * the failure and pass it up to JUnit.
     */
    public void runTest() throws IOException {
        Template cTemplate;
        StringWriter cWriter = new StringWriter();

        TemplateExceptionListener cListener = new HtmlFormattedExceptionListener();
        TemplateEventAdapter cAdapter = new TemplateEventAdapter();

        cAdapter.addTemplateExceptionListener( cListener );

        cTemplate = TemplateFactory.INSTANCE.createFromString(m_aTemplateText);
        //System.out.println( cTemplate.toString() );

        // Process the template.
        TemplateProcessorParameters p = TemplateProcessorParameters
                .newInstance(cWriter)
                .withModel(modelRoot)
                .withEventHandler(cAdapter);
        cTemplate.process(p);

        showTestResults(m_aFilename, m_aReferenceText, cWriter.toString() );
    }

    /**
     * Small test suite for this test case.
     */
    public static Test suite() {
        TestSuite suite = new TestSuite();
        suite.addTest( new TestException3( "testException3" ));
        return suite;
    }

    /**
     * Bootstrap for the self-test code.
     *
     * @param args the command line arguments
     */
    public static void main( String args[] ) throws Exception {
        AbstractTestCase cTester = new TestException3( "test-exception3.html" );
        TestResult cResult = new TestResult();

        cTester.run( cResult );
    }

}
