/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2013 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.testcase;

import freemarker.ext.misc.Transforms;
import freemarker.template.FastHash;
import freemarker.template.FastScalar;
import freemarker.template.Template;
import freemarker.template.TemplateFactory;
import junit.framework.TestResult;

import java.io.IOException;
import java.io.StringWriter;

/**
 * Test class for testing FM-Classic's functions (also known as Macros under
 * different template engines). This tests the scoping of inner functions,
 * and whether they correctly interact with the outer model.
 *
 * @version $Id: TestFunction.java 1085 2013-03-29 04:07:57Z run2000 $
 */
public final class TestFunction2 extends AbstractTestCase {
    private FastHash modelRoot;

    /**
     * Constructor that passes the name of the test up to the JUnit
     * constructor.
     *
     * @param aTestname the name of the test
     */
    public TestFunction2(String aTestname) {
        super( aTestname );
    }

    /**
     * Set up the test case prior to running.
     */
    public void setUp() {
        setUpFiles( "test-function2.html" );

        // Make a template data model.
        modelRoot = new FastHash();
        modelRoot.put("message", new FastScalar("Hello, world!"));

        modelRoot.put( "message2", new FastScalar( "Hello & goodbye world. One is < two, but > zero."));
        modelRoot.put( "transforms", Transforms.getInstance() );
    }

    /**
     * Performs the test. A fail result will generate information about
     * the failure and pass it up to JUnit.
     */
    public void runTest() throws IOException {
        Template cTemplate;
        StringWriter cWriter = new StringWriter();

        cTemplate = TemplateFactory.INSTANCE.createFromString(m_aTemplateText);
        //System.out.println( cTemplate.toString() );

        // Process the template.
        cTemplate.process(modelRoot, cWriter);

        showTestResults(m_aFilename, m_aReferenceText, cWriter.toString());
    }

    /**
     * Bootstrap for the self-test code.
     */
    public static void main( String[] argc ) throws Exception {
        AbstractTestCase cTest = new TestFunction2( "test-function2.html" );
        TestResult cResults = new TestResult();

        cTest.run( cResults );
    }
}
