/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2004 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.testcase;

import freemarker.template.*;
import freemarker.ext.misc.*;
import java.io.IOException;
import java.io.StringWriter;

import junit.framework.*;

/**
 * Test class for the &lt;transform&gt; FM-Classic tag, and in particular
 * the {@link freemarker.ext.misc.JavaToHtml} transformation class.
 *
 * @version $Id: TestJavaTransform.java 1101 2013-04-01 04:17:32Z run2000 $
 */
public final class TestJavaTransform extends AbstractTestCase {
    private FastHash modelRoot;

    /**
     * Constructor that passes the name of the test up to the JUnit
     * constructor.
     *
     * @param aTestname the name of the test
     */
    public TestJavaTransform(String aTestname) {
        super( aTestname );
    }

    /**
     * Set up the test case prior to running.
     */
    public void setUp() {
        setUpFiles( "test-javatrans.html" );

        // Make a template data model.
        modelRoot = new FastHash();
        modelRoot.put("message", new FastScalar("Hello, world!"));
        modelRoot.put("javaToHtml", new JavaToHtml());

    }

    /**
     * Performs the test. A fail result will generate information about
     * the failure and pass it up to JUnit.
     */
    protected void runTest() throws IOException {
        Template cTemplate;
        StringWriter cWriter = new StringWriter();

        cTemplate = TemplateFactory.INSTANCE.createFromString(m_aTemplateText);
        //System.out.println( cTemplate.toString() );

        // Process the template.
        cTemplate.process(modelRoot, cWriter);

        showTestResults(m_aFilename, m_aReferenceText, cWriter.toString() );
    }

    /**
     * Main method for executing the test case.
     *
     * @param args the command line arguments
     */
    public static void main( String args[] ) throws Exception {
    	AbstractTestCase cTest = new TestJavaTransform( "test-javatrans.html" );
        TestResult  cResult = new TestResult();

        cTest.run( cResult );
    }

}
