/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2004 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.testcase;

import freemarker.template.*;
import freemarker.testcase.models.*;
import java.io.IOException;
import java.io.StringWriter;
import java.util.ArrayList;
import java.util.List;

import junit.framework.*;

/**
 * Test class for testing FM-Classic's number literal syntax.
 *
 * @version $Id: TestNumberLiteral.java 1101 2013-04-01 04:17:32Z run2000 $
 */
public final class TestNumberLiteral extends AbstractTestCase {
    private FastHash modelRoot;

    /**
     * Constructor that passes the name of the test up to the JUnit
     * constructor.
     *
     * @param aTestname the name of the test
     */
    public TestNumberLiteral( String aTestname ) {
        super( aTestname );
    }

    /**
     * Set up the test case prior to running.
     */
    public void setUp() {
        setUpFiles( "test-numberliteral.html" );

        // Make a template data model.
        FastHash cModel1 = new FastHash();

        cModel1.put( "1", new FastScalar( "one" ));
        cModel1.put( "12", new FastScalar( "twelve" ));
        cModel1.put( "2one", new FastScalar( "two-one" ));
        cModel1.put( "one2", new FastScalar( "one-two" ));

        List<FastScalar> modelList = new ArrayList<FastScalar>();

        modelList.add( new FastScalar( "zero" ));
        modelList.add( new FastScalar( "one" ));
        modelList.add( new FastScalar( "two" ));
        modelList.add( new FastScalar( "three" ));
        modelList.add( new FastScalar( "four" ));
        modelList.add( new FastScalar( "five" ));
        modelList.add( new FastScalar( "six" ));
        modelList.add( new FastScalar( "seven" ));
        modelList.add( new FastScalar( "eight" ));
        modelList.add( new FastScalar( "nine" ));
        modelList.add( new FastScalar( "tenth" ));
        modelList.add( new FastScalar( "eleven" ));
        modelList.add( new FastScalar( "twelve" ));

        FastList<?> cModel2 = new FastList<FastScalar>( modelList );

        modelRoot = new FastHash();
        modelRoot.put( "message", new FastScalar( "Hello, world!" ));
        modelRoot.put( "foo", new FastScalar( "bar" ));
        modelRoot.put( "one", new FastScalar( "1" ));
        modelRoot.put( "1", new FastScalar( "one" ));
        modelRoot.put( "12", new FastScalar( "twelve" ));
        modelRoot.put( "2one", new FastScalar( "two-one" ));
        modelRoot.put( "one2", new FastScalar( "one-two" ));
        modelRoot.put( "hash", cModel1 );
        modelRoot.put( "list", cModel2 );
        modelRoot.put( "call", new SimpleTestMethod() );
    }

    /**
     * Performs the test. A fail result will generate information about
     * the failure and pass it up to JUnit.
     */
    public void runTest() throws IOException {
        Template cTemplate;
        StringWriter cWriter = new StringWriter();

        cTemplate = TemplateFactory.INSTANCE.createFromString(m_aTemplateText);
        //System.out.println( cTemplate.toString() );

        // Process the template.
        cTemplate.process(modelRoot, cWriter);

        showTestResults(m_aFilename, m_aReferenceText, cWriter.toString() );
    }

    /**
     * Bootstrap for the self-test code.
     */
    public static void main( String[] argc ) throws Exception {
        AbstractTestCase cTest = new TestNumberLiteral( "test-numberliteral.html" );
        TestResult cResults = new TestResult();

        cTest.run( cResults );
    }
}
