/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2004 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.testcase;

import freemarker.template.*;
import freemarker.ext.misc.Substitute;
import freemarker.ext.misc.Split;
import freemarker.ext.misc.Match;
import freemarker.ext.misc.Join;
import freemarker.ext.misc.Translate;

import java.io.IOException;
import java.io.StringWriter;

import junit.framework.*;

/**
 * Test class for testing the FM-Classic's extension for the Perl 5 methods.
 * These are implemented as method models operating on strings.
 *
 * @version $Id: TestPerl5Methods.java 1112 2013-04-12 02:59:25Z run2000 $
 */
public final class TestPerl5Methods extends AbstractTestCase {
    private FastHash modelRoot;

    /**
     * Constructor that passes the name of the test up to the JUnit
     * constructor.
     *
     * @param aTestname the name of the test
     */
    public TestPerl5Methods( String aTestname ) {
        super( aTestname );
    }

    /**
     * Set up the test case prior to running.
     */
    public void setUp() {
        setUpFiles( "test-perl5methods.html" );

        // Make a template data model.
        modelRoot = new FastHash();
        modelRoot.put("message", new FastScalar("Hello, world!"));
        modelRoot.put("substitute", new Substitute());
        modelRoot.put("split", new Split());
        modelRoot.put("join", Join.getInstance());
        modelRoot.put("translate", new Translate());
        modelRoot.put("match", new Match());
    }

    /**
     * Performs the test. A fail result will generate information about
     * the failure and pass it up to JUnit.
     */
    public void runTest() throws IOException {
        Template cTemplate;
        StringWriter cWriter = new StringWriter();

        cTemplate = TemplateFactory.INSTANCE.createFromString(m_aTemplateText);
        //System.out.println( cTemplate.toString() );

        // Process the template.
        cTemplate.process(modelRoot, cWriter);

        showTestResults(m_aFilename, m_aReferenceText, cWriter.toString() );
    }

    /**
     * Bootstrap for the self-test code.
     */
    public static void main( String[] argc ) throws Exception {
        AbstractTestCase cTest = new TestPerl5Methods( "test-perl5methods.html" );
        TestResult cResults = new TestResult();

        cTest.run( cResults );
    }
}
