/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2004 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.testcase;

import freemarker.template.*;
import java.io.IOException;
import java.io.StringWriter;
import java.util.ArrayList;
import java.util.List;

import junit.framework.*;

/**
 * Test class for testing FM-Classic variable syntax, in particular,
 * the chaining of variables using dot and dynamic-key-name.
 *
 * @version $Id: TestVariables.java 1101 2013-04-01 04:17:32Z run2000 $
 */
public final class TestVariables extends AbstractTestCase {
    private FastHash modelRoot;

    /**
     * Constructor that passes the name of the test up to the JUnit
     * constructor.
     *
     * @param aTestname the name of the test
     */
    public TestVariables(String aTestname) {
        super( aTestname );
    }

    /**
     * Set up the test case prior to running.
     */
    public void setUp() {
        setUpFiles( "test-variables.html" );

        // Make a template data model.
        modelRoot = new FastHash();
        modelRoot.put("message", new FastScalar("Hello, world!"));

        List<FastScalar> modelList = new ArrayList<FastScalar>();
        FastHash cModel2 = new FastHash();
        FastHash cModel3 = new FastHash();
        FastHash cModel4 = new FastHash();

        modelList.add( new FastScalar( "one" ));
        modelList.add( new FastScalar( "two" ));
        modelList.add( new FastScalar( "three" ));
        modelList.add( new FastScalar( "four" ));
        modelList.add( new FastScalar( "five" ));

        FastList<?> cModel1 = new FastList<FastScalar>( modelList );

        cModel2.put( "output", new FastScalar( "My message." ));
        cModel2.put( "key", cModel1 );
        cModel3.put( "value", cModel2 );
        cModel4.put( "mykey", new FastScalar( "key" ));
        cModel4.put( "_test", new FastScalar( "out" ));

        modelRoot.put( "list", cModel1 );
        modelRoot.put( "hash", cModel2 );
        modelRoot.put( "hash2", cModel3 );
        modelRoot.put( "items", cModel4 );
    }

    /**
     * Performs the test. A fail result will generate information about
     * the failure and pass it up to JUnit.
     */
    public void runTest() throws IOException {
        Template cTemplate;
        StringWriter cWriter = new StringWriter();

        cTemplate = TemplateFactory.INSTANCE.createFromString(m_aTemplateText);
        //System.out.println( cTemplate.toString() );

        // Process the template.
        cTemplate.process(modelRoot, cWriter);

        showTestResults(m_aFilename, m_aReferenceText, cWriter.toString() );
    }

    /**
     * Bootstrap for the self-test code.
     */
    public static void main( String[] argc ) throws Exception {
        AbstractTestCase cTest = new TestVariables( "test-variables.html" );
        TestResult cResults = new TestResult();

        cTest.run( cResults );
    }
}
