/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2004 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.testcase.beans;

import java.util.*;
import java.math.BigInteger;
import java.math.BigDecimal;

/**
 * Simple bean for use with the <code>TestBeanModels</code> test case.
 *
 * @version $Id: SimpleBean.java 1101 2013-04-01 04:17:32Z run2000 $
 */
public final class SimpleBean {
    private byte byteValue;
    private int intValue;
    private long longValue;
    private short shortValue;

    private String message;

    private Double doubleObject;
    private Float floatObject;

    public List list2;

    private Set randomSet;

    /**
     * Default constructor that sets up a bunch of values so that the
     * <code>freemarker.ext.beans</code> package can find them.
     */
    public SimpleBean() {
        byteValue = 127;
        intValue = 5;
        longValue = -10;
        shortValue = 42;
        doubleObject = new Double( 3.14D );
        floatObject = new Float( 3.5F );
        message = "Hello, world!";
        randomSet = new TreeSet();
        randomSet.add( "test1" );
        randomSet.add( "test2" );
        randomSet.add( "test3" );
    }

    /** Retrieve an integer value from the bean. */
    public int getIntValue() {
        return intValue;
    }

    /** Retrieve a long value from the bean. */
    public long getLongValue() {
        return longValue;
    }

    /** Retrieve a short value from the bean. */
    public short getShortValue() {
        return shortValue;
    }

    /** Retrieve a byte value from the bean. */
    public byte getByteValue() {
        return byteValue;
    }

    /** Sets the bean with a short value. */
    public void setShortValue( short shortValue ) {
        this.shortValue = shortValue;
    }

    /** Retrieve a string value from the bean. */
    public String getMessage() {
        return message;
    }

    /** Retrieve a double object from the bean. */
    public Double getDoubleObject() {
        return doubleObject;
    }

    /** Retrieve a float object from the bean. */
    public Float getFloatObject() {
        return floatObject;
    }

    /** Retrieve a Set object from the bean. */
    public Set getRandomSet() {
        return randomSet;
    }

    /** Method call to check for method overloading. */
    public int checkList( List arguments ) {
        return arguments.size();
    }

    /** Method call to check for method overloading. */
    public int checkMap( Map arguments ) {
        return arguments.size();
    }

    public void setArray1( boolean[] array ) {
        // Do nothing
    }

    public void setArray2( Integer[] array ) {
        // Do nothing
    }

    public void setArray3( String[] array ) {
        // Do nothing
    }

    public void setArray4( int[] array ) {
        // Do nothing
    }

    public void setArray5( Number[] array ) {
        // Do nothing
    }

    public void setArray6( Object[] array ) {
        // Do nothing
    }

    public void setVector( Vector list ) {
        // Do nothing
    }

    public void setList( List list ) {
        // Do nothing
    }

    public void setSet( Set set ) {
        // Do nothing
    }

    public void setSortedSet( SortedSet set ) {
        randomSet = set;
    }

    public void setLinkedList( LinkedList list ) {
        list2 = list;
    }

    public void setBigInt( BigInteger bi1 ) {
        // Do nothing
    }

    public void setBigDecimal( BigDecimal bd1 ) {
        // Do nothing
    }

    public void setDouble( double d ) {
        doubleObject = new Double( d );
    }

    public void setFloat( float f ) {
        floatObject = new Float( f );
    }
}
