/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2004 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.testcase.models;

import freemarker.template.*;

/**
 * Model for testing the impact of the <code>isEmpty()</code> method on
 * template list models. Every other method simply delegates to a
 * {@link freemarker.template.FastList} model.
 *
 * @author  <a href="mailto:run2000@users.sourceforge.net">Nicholas Cull</a>
 * @version $Id: BooleanList2.java 1101 2013-04-01 04:17:32Z run2000 $
 * @see BooleanList1
 */
public final class BooleanList2 implements TemplateListModel2, TemplateIndexedModel {
    private FastList  cList;

    /** Creates new BooleanList2. */
    public BooleanList2() {
        cList = new FastList();
    }

    /**
     * Retrieves an iterator to iterate over this list.
     *
     * @return an iterator to iterate over the current list.
     * @throws TemplateModelException the next item in the list can't be
     * retrieved, or no next item exists.
     */
    public TemplateIteratorModel templateIterator() throws TemplateModelException {
        return cList.templateIterator();
    }

    /**
     * Returns the used iterator to the list model.
     *
     * @param iterator the iterator to be returned to the object pool
     */
    public void releaseIterator(TemplateIteratorModel iterator) {
        cList.releaseIterator( iterator );
    }

    /**
     * Retrieves the specified item from the list.
     *
     * @param index the index of the item to be retrieved.
     * @return the specified index in the list.
     * @throws TemplateModelException the specified item in the list can't be
     * retrieved, or the index is out of bounds.
     */
    public TemplateModel getAtIndex(long index) throws TemplateModelException {
        return cList.getAtIndex(index);
    }

    /**
     * Is the underlying <code>List</code> empty?
     *
     * @return <code>true</code> if the list is empty, otherwise <code>false</code>
     */
    public boolean isEmpty() throws TemplateModelException {
        return false;
    }

}
