/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2004 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.testcase.models;

import freemarker.template.*;
import freemarker.ext.misc.*;

import java.util.HashMap;
import java.util.Map;

/**
 * Part of the TestTransform testcase suite.
 *
 * @author  <a href="mailto:run2000@users.sourceforge.net">Nicholas Cull</a>
 * @version $Id: TransformHashWrapper.java 1101 2013-04-01 04:17:32Z run2000 $
 */
public final class TransformHashWrapper implements TemplateHashModel,
        TemplateScalarModel {

    private TemplateHashModel m_cHashModel;

    /** Creates new TransformHashWrapper */
    public TransformHashWrapper() {
        Map<String, TemplateModel> hashModel = new HashMap<String, TemplateModel>();

        hashModel.put( "htmlEscape", HtmlEscape.getInstance() );
        hashModel.put( "compress", LegacyCompress.getInstance() );
        hashModel.put( "escape", new TransformMethodWrapper1() );
        hashModel.put( "special", new TransformMethodWrapper2() );
        hashModel.put( "special2", new TransformMethodWrapper3() );

        m_cHashModel = new FastHash<TemplateModel>( hashModel );
    }

    /**
     * Gets a {@link freemarker.template.TemplateModel} from the hash.
     *
     * @param key the name by which the <code>TemplateModel</code>
     * is identified in the template.
     * @return the <code>TemplateModel</code> referred to by the key,
     * or <code>null</code> if not found.
     */
    public TemplateModel get(String key) throws TemplateModelException {
        return m_cHashModel.get( key );
    }

    /**
     * Is the model empty?
     *
     * @return <code>false</code> to indicate the model is not empty
     */
    public boolean isEmpty() throws TemplateModelException {
        return false;
    }

    /**
     * Returns the scalar's value as a <code>String</code>.
     *
     * @return the <code>String</code> value of this scalar.
     */
    public String getAsString() throws TemplateModelException {
        return "Utility transformations";
    }

}
