/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2004 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.testcase.models;

import java.util.*;
import freemarker.template.*;

/**
 * Another test of the interaction between MethodModels and TransformModels.
 *
 * @version $Id: TransformMethodWrapper3.java 1101 2013-04-01 04:17:32Z run2000 $
 * @see freemarker.testcase.models.TransformMethodWrapper3
 */
public final class TransformMethodWrapper3 implements TemplateMethodModel {

    /** Creates new TransformMethodWrapper1 */
    public TransformMethodWrapper3() {
    }

    /**
     * Executes a method call.
     *
     * @param arguments a <code>List</code> of <code>String</code> objects containing
     * the values of the arguments passed to the method.
     * @return the <code>TemplateModel</code> produced by the method,
     * or <code>null</code>.
     */
    public TemplateModel exec(List<String> arguments) throws TemplateModelException {
        TransformModel2 cTransformer = new TransformModel2();

        // Sets up properties of the Transform model based on the arguments
        // passed into this method

        for( String aArgument : arguments ) {

            if( "quote".equals(aArgument)) {
                cTransformer.setQuotes( true );
            } else if( "tag".equals(aArgument)) {
                cTransformer.setTags( true );
            } else if( "ampersand".equals(aArgument)) {
                cTransformer.setAmpersands( true );
            } else {
                cTransformer.setComment( aArgument );
            }
        }

        // Now return the transform class.
        return cTransformer;
    }

    /**
     * Is the model empty?
     *
     * @return <code>false</code> to indicate the model is not empty
     */
    public boolean isEmpty() throws TemplateModelException {
        return false;
    }

}
